@@ -1,4 +1,6 @@
 from .base_loader import BaseLoader
+from .callable_loader import CallableLoader
+from .dict_loader import DictLoader
 from .env_loader import EnvLoader
 from .ssm_loader import SSMLoader
 from .config_parser_loader import ConfigParserLoader
\ No newline at end of file
